@@ -26,6 +26,9 @@ PipeOpTorchConv = R6Class("PipeOpTorchConv",
     }
   ),
   private = list(
+    .additional_phash_input = function() {
+      list(private$.d)
+    },
     .shapes_out = function(shapes_in, param_vals, task) {
       list(conv_output_shape(
         shape_in = shapes_in[[1]],
@@ -160,4 +163,3 @@ conv_output_shape = function(shape_in, conv_dim, padding, dilation, stride, kern
     (if (ceil_mode) base::ceiling else base::floor)((shape_tail + 2 * padding - dilation * (kernel_size - 1) - 1) / stride + 1)
   )
 }
-
