@@ -1,3 +1,7 @@
+single_param_group = function(params) {
+  return(params)
+}
+
 #' @title Convert to TorchOptimizer
 #'
 #' @description
@@ -41,11 +45,11 @@ as_torch_optimizer.character = function(x, clone = FALSE, ...) { # nolint
 #' @title Torch Optimizer
 #'
 #' @description
-#' This wraps a `torch::torch_optimizer_generator`a and annotates it with metadata, most importantly a [`ParamSet`][paradox::ParamSet].
+#' This wraps a `torch::torch_optimizer_generator` and annotates it with metadata, most importantly a [`ParamSet`][paradox::ParamSet].
 #' The optimizer is created for the given parameter values by calling the `$generate()` method.
 #'
 #' This class is usually used to configure the optimizer of a torch learner, e.g.
-#' when construcing a learner or in a [`ModelDescriptor`].
+#' when constructing a learner or in a [`ModelDescriptor`].
 #'
 #' For a list of available optimizers, see [`mlr3torch_optimizers`].
 #' Items from this dictionary can be retrieved using [`t_opt()`].
@@ -53,12 +57,12 @@ as_torch_optimizer.character = function(x, clone = FALSE, ...) { # nolint
 #' @section Parameters:
 #' Defined by the constructor argument `param_set`.
 #' If no parameter set is provided during construction, the parameter set is constructed by creating a parameter
-#' for each argument of the wrapped loss function, where the parametes are then of type [`ParamUty`][paradox::Domain].
+#' for each argument of the wrapped loss function, where the parameters are then of type [`ParamUty`][paradox::Domain].
 #'
 #' @family Torch Descriptor
 #' @export
 #' @examplesIf torch::torch_is_installed()
-#' # Create a new torch loss
+#' # Create a new torch optimizer
 #' torch_opt = TorchOptimizer$new(optim_ignite_adam, label = "adam")
 #' torch_opt
 #' # If the param set is not specified, parameters are inferred but are of class ParamUty
@@ -109,6 +113,9 @@ TorchOptimizer = R6::R6Class("TorchOptimizer",
       } else {
         param_set = inferps(torch_optimizer, ignore = "params")
       }
+      param_set = c(param_set,
+        ps(param_groups = p_uty(custom_check = check_function, tags = "train"))
+      )
       super$initialize(
         generator = torch_optimizer,
         id = id,
@@ -125,7 +132,15 @@ TorchOptimizer = R6::R6Class("TorchOptimizer",
     #' @return `torch_optimizer`
     generate = function(params) {
       require_namespaces(self$packages)
-      invoke(self$generator, .args = self$param_set$get_values(), params = params)
+      pvs = self$param_set$get_values()
+      param_groups_fn = pvs$param_groups
+
+      if (!is.null(param_groups_fn)) {
+        pvs$param_groups = NULL
+        params = param_groups_fn(params)
+      }
+
+      invoke(self$generator, .args = pvs, params = params)
     }
   ),
   private = list(
@@ -278,7 +293,6 @@ mlr3torch_optimizers$add("adam",
   }
 )
 
-
 mlr3torch_optimizers$add("sgd",
   function() {
     p = ps(
@@ -298,8 +312,6 @@ mlr3torch_optimizers$add("sgd",
   }
 )
 
-
-
 mlr3torch_optimizers$add("rmsprop",
   function() {
     p = ps(
@@ -320,7 +332,6 @@ mlr3torch_optimizers$add("rmsprop",
   }
 )
 
-
 mlr3torch_optimizers$add("adagrad",
   function() {
     p = ps(
